[![Downloads](https://static.pepy.tech/personalized-badge/indsl?period=total&units=international_system&left_color=black&right_color=brightgreen&left_text=PyPi%20Downloads)](https://pepy.tech/project/indsl) [![Code Quality](https://github.com/cognitedata/indsl/actions/workflows/code-quality.yaml/badge.svg)](https://github.com/cognitedata/indsl/actions/workflows/code-quality.yaml) [![CodeQL](https://github.com/cognitedata/indsl/actions/workflows/codeql-analysis.yml/badge.svg)](https://github.com/cognitedata/indsl/actions/workflows/codeql-analysis.yml) [![codecov](https://codecov.io/gh/cognitedata/indsl/branch/master/graph/badge.svg?token=N63jUovh1o)](https://codecov.io/gh/cognitedata/indsl)<!-- ALL-CONTRIBUTORS-BADGE:START - Do not remove or modify this section -->
[![All Contributors](https://img.shields.io/badge/all_contributors-11-orange.svg?style=flat-square)](#contributors-)
<!-- ALL-CONTRIBUTORS-BADGE:END -->

<a href="https://cognite.com/">
    <img src="https://github.com/cognitedata/cognite-python-docs/blob/master/img/cognite_logo.png" alt="Cognite logo" title="Cognite" align="right" height="80" />
</a>

Industrial Data Science Library
=========================================

This is Cognite's collection of data science algorithms and models. Its objective is twofold. First, empower domain
experts to conduct exploratory work, root cause analysis, and analyze data via <a href="https://charts.cogniteapp.com/" target="_blank">Cognite Charts</a>.
Second, curate a collection industry relevant data science algorithms to be used as a regular python package.
For more information, consult the <a href="https://docs.cognite.com/cdf/charts/" target="_blank">Charts documentation page</a>.

## Documentation
* [InDSL Home](https://indsl.docs.cognite.com/)
* [Data Science Developer Guidelines](https://indsl.docs.cognite.com/contribute.html)
* [Gallery of Charts - Examples](https://indsl.docs.cognite.com/auto_examples/index.html)
* [Publishing new versions of InDSL](./PUBLISHING.md)

## Contributors ✨

Thanks goes to these wonderful people ([emoji key](https://allcontributors.org/docs/en/emoji-key)):

<!-- ALL-CONTRIBUTORS-LIST:START - Do not remove or modify this section -->
<!-- prettier-ignore-start -->
<!-- markdownlint-disable -->
<table>
  <tr>
    <td align="center"><a href="https://github.com/gzarruk"><img src="https://avatars.githubusercontent.com/u/24595022?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Gustavo</b></sub></a><br /><a href="https://github.com/cognitedata/indsl/commits?author=gzarruk" title="Documentation">📖</a> <a href="https://github.com/cognitedata/indsl/pulls?q=is%3Apr+reviewed-by%3Agzarruk" title="Reviewed Pull Requests">👀</a> <a href="#talk-gzarruk" title="Talks">📢</a> <a href="https://github.com/cognitedata/indsl/commits?author=gzarruk" title="Tests">⚠️</a> <a href="#data-gzarruk" title="Data">🔣</a> <a href="#content-gzarruk" title="Content">🖋</a> <a href="https://github.com/cognitedata/indsl/commits?author=gzarruk" title="Code">💻</a> <a href="#ideas-gzarruk" title="Ideas, Planning, & Feedback">🤔</a></td>
    <td align="center"><a href="https://github.com/funsim"><img src="https://avatars.githubusercontent.com/u/763150?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Simon Funke</b></sub></a><br /><a href="https://github.com/cognitedata/indsl/commits?author=funsim" title="Code">💻</a> <a href="https://github.com/cognitedata/indsl/commits?author=funsim" title="Tests">⚠️</a> <a href="https://github.com/cognitedata/indsl/issues?q=author%3Afunsim" title="Bug reports">🐛</a></td>
    <td align="center"><a href="https://github.com/neringaalt"><img src="https://avatars.githubusercontent.com/u/8692658?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Neringa Altanaite</b></sub></a><br /><a href="https://github.com/cognitedata/indsl/commits?author=neringaalt" title="Code">💻</a> <a href="https://github.com/cognitedata/indsl/pulls?q=is%3Apr+reviewed-by%3Aneringaalt" title="Reviewed Pull Requests">👀</a> <a href="https://github.com/cognitedata/indsl/commits?author=neringaalt" title="Tests">⚠️</a> <a href="https://github.com/cognitedata/indsl/commits?author=neringaalt" title="Documentation">📖</a></td>
    <td align="center"><a href="https://www.linkedin.com/in/rhuanbarreto/"><img src="https://avatars.githubusercontent.com/u/283004?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Rhuan Barreto</b></sub></a><br /><a href="#tool-rhuanbarreto" title="Tools">🔧</a> <a href="#security-rhuanbarreto" title="Security">🛡️</a> <a href="https://github.com/cognitedata/indsl/pulls?q=is%3Apr+reviewed-by%3Arhuanbarreto" title="Reviewed Pull Requests">👀</a> <a href="#ideas-rhuanbarreto" title="Ideas, Planning, & Feedback">🤔</a> <a href="#infra-rhuanbarreto" title="Infrastructure (Hosting, Build-Tools, etc)">🚇</a></td>
    <td align="center"><a href="https://github.com/evertoncolling"><img src="https://avatars.githubusercontent.com/u/33816483?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Everton Colling</b></sub></a><br /><a href="https://github.com/cognitedata/indsl/commits?author=evertoncolling" title="Code">💻</a> <a href="#data-evertoncolling" title="Data">🔣</a> <a href="https://github.com/cognitedata/indsl/commits?author=evertoncolling" title="Documentation">📖</a> <a href="https://github.com/cognitedata/indsl/commits?author=evertoncolling" title="Tests">⚠️</a></td>
    <td align="center"><a href="https://github.com/redzarosliCognite"><img src="https://avatars.githubusercontent.com/u/91888036?v=4?s=100" width="100px;" alt=""/><br /><sub><b>redzarosliCognite</b></sub></a><br /><a href="https://github.com/cognitedata/indsl/commits?author=redzarosliCognite" title="Code">💻</a> <a href="https://github.com/cognitedata/indsl/pulls?q=is%3Apr+reviewed-by%3AredzarosliCognite" title="Reviewed Pull Requests">👀</a> <a href="#ideas-redzarosliCognite" title="Ideas, Planning, & Feedback">🤔</a> <a href="https://github.com/cognitedata/indsl/commits?author=redzarosliCognite" title="Documentation">📖</a> <a href="#example-redzarosliCognite" title="Examples">💡</a> <a href="#question-redzarosliCognite" title="Answering Questions">💬</a> <a href="#userTesting-redzarosliCognite" title="User Testing">📓</a></td>
    <td align="center"><a href="https://github.com/MortGron"><img src="https://avatars.githubusercontent.com/u/42722577?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Morten Grønbech</b></sub></a><br /><a href="https://github.com/cognitedata/indsl/commits?author=MortGron" title="Code">💻</a> <a href="#example-MortGron" title="Examples">💡</a> <a href="https://github.com/cognitedata/indsl/commits?author=MortGron" title="Documentation">📖</a> <a href="https://github.com/cognitedata/indsl/pulls?q=is%3Apr+reviewed-by%3AMortGron" title="Reviewed Pull Requests">👀</a> <a href="#question-MortGron" title="Answering Questions">💬</a> <a href="#ideas-MortGron" title="Ideas, Planning, & Feedback">🤔</a></td>
  </tr>
  <tr>
    <td align="center"><a href="https://github.com/Anitsirc22"><img src="https://avatars.githubusercontent.com/u/38993790?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Cristina Ferrer</b></sub></a><br /><a href="https://github.com/cognitedata/indsl/commits?author=Anitsirc22" title="Code">💻</a> <a href="#example-Anitsirc22" title="Examples">💡</a> <a href="#ideas-Anitsirc22" title="Ideas, Planning, & Feedback">🤔</a> <a href="https://github.com/cognitedata/indsl/pulls?q=is%3Apr+reviewed-by%3AAnitsirc22" title="Reviewed Pull Requests">👀</a></td>
    <td align="center"><a href="http://treiderphoto.com"><img src="https://avatars.githubusercontent.com/u/8521241?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Håkon V. Treider</b></sub></a><br /><a href="https://github.com/cognitedata/indsl/commits?author=haakonvt" title="Code">💻</a> <a href="https://github.com/cognitedata/indsl/pulls?q=is%3Apr+reviewed-by%3Ahaakonvt" title="Reviewed Pull Requests">👀</a> <a href="#ideas-haakonvt" title="Ideas, Planning, & Feedback">🤔</a> <a href="#infra-haakonvt" title="Infrastructure (Hosting, Build-Tools, etc)">🚇</a></td>
    <td align="center"><a href="https://github.com/KeepFloyding"><img src="https://avatars.githubusercontent.com/u/29730122?v=4?s=100" width="100px;" alt=""/><br /><sub><b>Andris Piebalgs</b></sub></a><br /><a href="https://github.com/cognitedata/indsl/commits?author=KeepFloyding" title="Code">💻</a> <a href="https://github.com/cognitedata/indsl/pulls?q=is%3Apr+reviewed-by%3AKeepFloyding" title="Reviewed Pull Requests">👀</a> <a href="#example-KeepFloyding" title="Examples">💡</a></td>
    <td align="center"><a href="https://github.com/kbrattli"><img src="https://avatars.githubusercontent.com/u/45734104?v=4?s=100" width="100px;" alt=""/><br /><sub><b>kbrattli</b></sub></a><br /><a href="https://github.com/cognitedata/indsl/commits?author=kbrattli" title="Code">💻</a> <a href="https://github.com/cognitedata/indsl/commits?author=kbrattli" title="Documentation">📖</a> <a href="#maintenance-kbrattli" title="Maintenance">🚧</a> <a href="https://github.com/cognitedata/indsl/commits?author=kbrattli" title="Tests">⚠️</a></td>
  </tr>
</table>

<!-- markdownlint-restore -->
<!-- prettier-ignore-end -->

<!-- ALL-CONTRIBUTORS-LIST:END -->

This project follows the [all-contributors](https://github.com/all-contributors/all-contributors) specification. Contributions of any kind welcome!
